/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.common;

import java.time.ZonedDateTime;

import de.ozgcloud.archive.file.OzgFile;
import de.xoev.xdomea.AnlageDokumentType;

public class AnlageDokumentTypeBuilder {
	private OzgFile ozgFile;
	private ZonedDateTime createdAt;

	public static AnlageDokumentTypeBuilder builder() {
		return new AnlageDokumentTypeBuilder();
	}

	public AnlageDokumentTypeBuilder withOzgFile(OzgFile ozgFile) {
		this.ozgFile = ozgFile;
		return this;
	}

	public AnlageDokumentTypeBuilder withCreatedAt(ZonedDateTime createdAt) {
		this.createdAt = createdAt;
		return this;
	}

	public AnlageDokumentType build() {
		var anlage = new AnlageDokumentType();
		anlage.setIdentifikation(IdentifikationObjektTypeBuilder.builder()
				.withObjectID(ozgFile.getId().toString())
				.build());
		anlage.getVersion().add(VersionTypeBuilder.builder()
				.withCreatedAt(createdAt)
				.withOzgFile(ozgFile).build());
		return anlage;
	}

}
