/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.common.binaryfile;

import org.mapstruct.AnnotateWith;
import org.mapstruct.AnnotateWith.Element;
import org.mapstruct.Mapper;
import org.springframework.stereotype.Component;

import de.ozgcloud.apilib.file.OzgCloudFileId;
import de.ozgcloud.archive.ArchiveManagerConfiguration;
import de.ozgcloud.common.binaryfile.FileId;

@Mapper
@AnnotateWith(value = Component.class, elements = @Element(strings = ArchiveManagerConfiguration.FILE_ID_MAPPER_NAME))
public interface FileIdMapper {

	default FileId fromString(String fileId) {
		return FileId.from(fileId);
	}

	default String toString(FileId fileId) {
		return fileId.toString();
	}

	default FileId fromOzgCloudFileId(OzgCloudFileId ozgCloudFileId) {
		return FileId.from(ozgCloudFileId.toString());
	}

	default OzgCloudFileId toOzgCloudFileId(FileId fileId) {
		return OzgCloudFileId.from(fileId.toString());
	}
}
