/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.common.command;

import java.util.Optional;
import java.util.stream.Stream;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import de.ozgcloud.apilib.common.callcontext.OzgCloudCallContextAttachingInterceptor;
import de.ozgcloud.apilib.common.callcontext.OzgCloudCallContextProvider;
import de.ozgcloud.archive.ArchiveManagerConfiguration;
import de.ozgcloud.vorgang.grpc.command.CommandServiceGrpc.CommandServiceBlockingStub;
import de.ozgcloud.vorgang.grpc.command.GrpcExistsPendingCommandsRequest;
import de.ozgcloud.vorgang.grpc.command.GrpcFindCommandsRequest;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.client.inject.GrpcClient;

@RequiredArgsConstructor
@Service(ArchiveManagerConfiguration.COMMAND_REMOTE_SERVICE_NAME)
class CommandRemoteService {

	@GrpcClient(ArchiveManagerConfiguration.GRPC_VORGANG_MANAGER_CLIENT_NAME)
	private final CommandServiceBlockingStub grpcService;
	@Qualifier(ArchiveManagerConfiguration.COMMAND_MAPPER_NAME)
	private final CommandMapper mapper;
	@Qualifier(ArchiveManagerConfiguration.CALL_CONTEXT_PROVIDER_NAME)
	private final OzgCloudCallContextProvider contextProvider;

	public Stream<ArchiveManagerCommand> findCommands(String vorgangId, Optional<String> status, Optional<String> order) {
		var response = getGrpcServiceWithInterceptor().findCommands(buildFindCommandsRequest(vorgangId, status, order));

		return response.getCommandList().stream().map(mapper::fromGrpc);
	}

	private GrpcFindCommandsRequest buildFindCommandsRequest(String vorgangId, Optional<String> status, Optional<String> order) {
		var builder = GrpcFindCommandsRequest.newBuilder()
				.setVorgangId(vorgangId);

		status.ifPresent(builder::addStatus);
		order.ifPresent(builder::setOrderString);

		return builder.build();
	}

	public boolean hasPendingCommands(String vorgangId) {
		var response = getGrpcServiceWithInterceptor().existsPendingCommands(buildHasPendingCommandRequest(vorgangId));
		return response.getExistsPendingCommands();
	}

	GrpcExistsPendingCommandsRequest buildHasPendingCommandRequest(String vorgangId) {
		return GrpcExistsPendingCommandsRequest.newBuilder().setVorgangId(vorgangId).build();
	}

	CommandServiceBlockingStub getGrpcServiceWithInterceptor() {
		return grpcService.withInterceptors(new OzgCloudCallContextAttachingInterceptor(contextProvider));
	}
}
