package de.ozgcloud.archive.common.xta;

import java.util.stream.Collectors;
import java.util.stream.Stream;

import de.ozgcloud.xta.client.model.XtaFile;
import de.xoev.xdomea.AbgabeImportBestaetigen0402;
import de.xoev.xdomea.ErfolgOderMisserfolgAbgabeType;
import lombok.RequiredArgsConstructor;

public class XtaImportConfirmationHandler {

	private final AbgabeImportBestaetigen0402 importConfirmation;

	public static XtaImportConfirmationHandler createFrom(XtaFile file) {
		return new XtaImportConfirmationHandler(file);
	}

	private XtaImportConfirmationHandler(XtaFile file) {
		importConfirmation = XtaFileReader.createAbgabeImportBestaetigen0402Reader().read(file);
	}

	public Stream<XtaAbgabeAdapter> getAbgaben() {
		return importConfirmation.getAbgegebenesObjekt().stream().map(XtaAbgabeAdapter::new);
	}

	@RequiredArgsConstructor
	public static class XtaAbgabeAdapter {

		private final ErfolgOderMisserfolgAbgabeType abgabeType;

		public String getVorgangId() {
			return abgabeType.getIDSGO();
		}

		public boolean isSuccessful() {
			return abgabeType.isErfolgreich();
		}

		public String getErrorMessage() {
			return abgabeType.getFehlermeldung().stream().collect(Collectors.joining(";"));
		}
	}
}