/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.export;

import java.util.Map;

import org.glassfish.jaxb.runtime.marshaller.NamespacePrefixMapper;
import org.springframework.stereotype.Component;

@Component
class XdomeaNamespacePrefixMapper extends NamespacePrefixMapper {

	static final String XDOMEA_NAMESPACE_URI = "urn:xoev-de:xdomea:schema:3.0.0";
	static final String XDOMEA_NAMESPACE_PREFIX = "xdomea";

	static final String XDOMEA_NAMESPACE_DINSPEC = "dinspec91379";
	static final String XDOMEA_NAMESPACE_DINSPEC_URI = "urn:xoev-de:kosit:xoev:datentyp:din-spec-91379_2019-03";

	static final String XDOMEA_NAMESPACE_GML = "gml";
	static final String XDOMEA_NAMESPACE_GML_URI = "http://www.opengis.net/gml/3.2";

	static final String XDOMEA_NAMESPACE_XOEV_CODE = "xoev-code";
	static final String XDOMEA_NAMESPACE_XOEV_CODE_URI = "http://xoev.de/schemata/code/1_0";

	static final String XDOMEA_NAMESPACE_XOEV_LC = "xoev-lc";
	static final String XDOMEA_NAMESPACE_XOEV_LC_URI = "http://xoev.de/latinchars/1_1/datatypes";

	private static final Map<String, String> NAMESPACE_MAP = Map.of(
			XDOMEA_NAMESPACE_URI, XDOMEA_NAMESPACE_PREFIX,
			XDOMEA_NAMESPACE_DINSPEC_URI, XDOMEA_NAMESPACE_DINSPEC,
			XDOMEA_NAMESPACE_GML_URI, XDOMEA_NAMESPACE_GML,
			XDOMEA_NAMESPACE_XOEV_CODE_URI, XDOMEA_NAMESPACE_XOEV_CODE,
			XDOMEA_NAMESPACE_XOEV_LC_URI, XDOMEA_NAMESPACE_XOEV_LC);

	@Override
	public String getPreferredPrefix(String namespaceUri, String suggestion, boolean requirePrefix) {
		return NAMESPACE_MAP.getOrDefault(namespaceUri, suggestion);
	}

	@Override
	public String[] getPreDeclaredNamespaceUris() {
		return new String[] {
				XDOMEA_NAMESPACE_DINSPEC_URI,
				XDOMEA_NAMESPACE_GML_URI,
				XDOMEA_NAMESPACE_XOEV_CODE_URI,
				XDOMEA_NAMESPACE_XOEV_LC_URI
		};
	}
}
