/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.postfach;

import java.util.stream.Stream;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import de.ozgcloud.archive.ArchiveManagerConfiguration;
import de.ozgcloud.nachrichten.postfach.GrpcFindPostfachMailsRequest;
import de.ozgcloud.nachrichten.postfach.PostfachServiceGrpc.PostfachServiceBlockingStub;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Service
class PostfachMailRemoteService {

	@GrpcClient(ArchiveManagerConfiguration.GRPC_VORGANG_MANAGER_CLIENT_NAME)
	private PostfachServiceBlockingStub grpcService;
	@Autowired
	private PostfachMailMapper postfachNachrichtMapper;

	public Stream<PostfachMail> findPostfachMails(String vorgangId) {
		var response = grpcService.findPostfachMails(buildFindPostfachMailsRequest(vorgangId));

		return response.getMailsList().stream().map(postfachNachrichtMapper::toPostfachMail);
	}

	private GrpcFindPostfachMailsRequest buildFindPostfachMailsRequest(String vorgangId) {
		return GrpcFindPostfachMailsRequest.newBuilder()
				.setVorgangId(vorgangId)
				.build();
	}
}