/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import static java.util.Objects.*;

import java.time.LocalDate;
import java.time.ZonedDateTime;
import java.util.Collection;

import org.mapstruct.Mapper;

import de.xoev.xdomea.DatatypeType;

@Mapper
interface DatatypeMapper {

	default DatatypeType from(Object object) {
		if (isNull(object)) {
			return DatatypeType.STRING;
		}
		var objectClass = object.getClass();
		if (String.class.equals(objectClass)) {
			return DatatypeType.STRING;
		}
		if (Integer.class.equals(objectClass)) {
			return DatatypeType.INTEGER;
		}
		if (Boolean.class.equals(objectClass)) {
			return DatatypeType.BOOLEAN;
		}
		if (LocalDate.class.equals(objectClass)) {
			return DatatypeType.DATE;
		}
		if (ZonedDateTime.class.equals(objectClass)) {
			return DatatypeType.DATETIME;
		}
		if (Float.class.equals(objectClass)) {
			return DatatypeType.FLOAT;
		}
		if (object instanceof Collection<?> collection && !collection.isEmpty()) {
			return from(collection.iterator().next());
		}
		return DatatypeType.STRING;
	}
}
