/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.stereotype.Service;

import de.ozgcloud.apilib.common.callcontext.OzgCloudCallContextAttachingInterceptor;
import de.ozgcloud.apilib.common.callcontext.OzgCloudCallContextProvider;
import de.ozgcloud.archive.ArchiveManagerConfiguration;
import de.ozgcloud.vorgang.vorgang.GrpcFindVorgangWithEingangRequest;
import de.ozgcloud.vorgang.vorgang.VorgangServiceGrpc.VorgangServiceBlockingStub;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.client.inject.GrpcClient;

@Service(ArchiveManagerConfiguration.VORGANG_REMOTE_MANAGER_SERVICE_NAME)
@RequiredArgsConstructor
class VorgangRemoteService {

	@GrpcClient(ArchiveManagerConfiguration.GRPC_VORGANG_MANAGER_CLIENT_NAME)
	private final VorgangServiceBlockingStub grpcService;

	@Qualifier(ArchiveManagerConfiguration.VORGANG_WITH_EINGANG_MAPPER_NAME)
	private final VorgangWithEingangMapper vorgangWithEingangMapper;

	@Qualifier(ArchiveManagerConfiguration.CALL_CONTEXT_PROVIDER_NAME)
	private final OzgCloudCallContextProvider contextProvider;

	public VorgangWithEingang findVorgangWithEingang(String vorgangId) {
		return vorgangWithEingangMapper
				.fromGrpc(getGrpcServiceWithInterceptor()
						.findVorgangWithEingang(buildFindVorgangWithEingangRequest(vorgangId))
						.getVorgangWithEingang());
	}

	GrpcFindVorgangWithEingangRequest buildFindVorgangWithEingangRequest(String id) {
		return GrpcFindVorgangWithEingangRequest.newBuilder()
				.setId(id)
				.build();
	}

	VorgangServiceBlockingStub getGrpcServiceWithInterceptor() {
		return grpcService.withInterceptors(new OzgCloudCallContextAttachingInterceptor(contextProvider));
	}
}
