package de.ozgcloud.archive.common.xta;

import static org.assertj.core.api.Assertions.*;
import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Spy;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.core.type.TypeReference;
import com.fasterxml.jackson.databind.ObjectMapper;

import de.ozgcloud.common.errorhandling.TechnicalException;
import lombok.SneakyThrows;

class JsonToXtaIdentifierListConverterTest {

	@InjectMocks
	private JsonToXtaIdentifierListConverter converter;

	@Spy
	private ObjectMapper objectMapper;

	@Nested
	class TestConvert {

		@Test
		void shouldReturnListOfXtaIdentifier() {
			var jsonInput = XtaIdentifierTestFactory.createAsJson();

			var identifiers = converter.convert(jsonInput);

			assertThat(identifiers).usingRecursiveFieldByFieldElementComparator().containsExactly(XtaIdentifierTestFactory.create());
		}

		@Test
		@SneakyThrows
		void shouldThrowTechnicalException() {
			doThrow(JsonProcessingException.class).when(objectMapper).readValue(anyString(), any(TypeReference.class));

			assertThrows(TechnicalException.class, () -> converter.convert("invalid input"));
		}
	}
}
