/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.export;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.Map;

import jakarta.xml.bind.Marshaller;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;
import org.springframework.oxm.jaxb.Jaxb2Marshaller;

class ExportConfigurationTest {

	@Spy
	@InjectMocks
	private ExportConfiguration configuration;

	@Mock
	private XdomeaNamespacePrefixMapper prefixMapper;

	@Nested
	class TestCreateMarshallerProperties {

		@Test
		void shouldFromatMarshalledXml() {
			var props = configuration.createMarshallerProperties();

			assertThat(props).containsEntry(Marshaller.JAXB_FORMATTED_OUTPUT, ExportConfiguration.JAXB_FORMATTED_OUTPUT);
		}

		@Test
		void shouldUseNamespacePrefixMapper() {
			var props = configuration.createMarshallerProperties();

			assertThat(props).containsEntry(ExportConfiguration.PROPERTY_NAMESPACE_PREFIX_MAPPER, prefixMapper);
		}
	}

	@Nested
	class TestMarshaller {

		private final Map<String, Object> marshallerProps = Map.of();

		@BeforeEach
		void init() {
			doReturn(marshallerProps).when(configuration).createMarshallerProperties();
		}

		@Test
		void shouldSetContextPath() {
			var marshaller = configuration.marshaller();

			assertThat(marshaller.getContextPath()).isEqualTo(ExportConfiguration.CONTEXT_PATH);
		}

		@Test
		void shouldCreateMarshallerProperties() {
			configuration.marshaller();

			verify(configuration).createMarshallerProperties();
		}

		@Test
		void shouldReturnMarshaller() {
			var marshaller = configuration.marshaller();

			assertThat(marshaller).isNotNull().isInstanceOf(Jaxb2Marshaller.class);
		}
	}

}