/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.file;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.apilib.file.OzgCloudFileId;
import de.ozgcloud.apilib.file.OzgCloudFileTestFactory;
import de.ozgcloud.archive.common.binaryfile.FileIdMapper;

class OzgFileMapperTest {

	@InjectMocks
	private final OzgFileMapper mapper = Mappers.getMapper(OzgFileMapper.class);

	@Mock
	private FileIdMapper fileIdmapper;

	@Nested
	class TestFromGrpc {

		@BeforeEach
		void callFileIdMapper() {
			when(fileIdmapper.fromString(any())).thenCallRealMethod();
		}

		@Test
		void shouldMap() {
			var file = mapper.fromGrpc(GrpcOzgFileTestFactory.create());

			assertThat(file).usingRecursiveComparison().isEqualTo(OzgFileTestFactory.create());
		}
	}

	@Nested
	class TestFromOzgCloudFile {

		@BeforeEach
		void callFileIdMapper() {
			when(fileIdmapper.fromOzgCloudFileId(any())).thenCallRealMethod();
		}

		@Test
		void shouldMap() {
			var file = mapper.fromOzgCloudFile(OzgCloudFileTestFactory.createBuilder()
					.id(OzgCloudFileId.from(OzgFileTestFactory.ID.toString()))
					.name(OzgFileTestFactory.NAME)
					.contentType(OzgFileTestFactory.CONTENT_TYPE)
					.build());

			assertThat(file).usingRecursiveComparison().isEqualTo(OzgFileTestFactory.create());
		}
	}
}