/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.kommentar;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.archive.common.TimeMapper;
import de.ozgcloud.vorgang.common.grpc.GrpcObjectMapper;

class KommentarMapperITCase {

	@InjectMocks
	private final KommentarMapper kommentarMapper = Mappers.getMapper(KommentarMapper.class);
	@Mock
	private GrpcObjectMapper grpcObjectMapper;
	@Mock
	private TimeMapper timeMapper;
	@Mock
	private AttachmentMapper attachmentMapper;

	@Nested
	class TestFromItem {

		@BeforeEach
		void setUpCallsOfDependentMappers() {
			when(grpcObjectMapper.mapFromGrpc(any())).thenCallRealMethod();
			when(grpcObjectMapper.mapProperty(any())).thenCallRealMethod();
			when(timeMapper.parseString(any())).thenCallRealMethod();
			when(attachmentMapper.mapAttachments(any())).thenCallRealMethod();
		}

		@Test
		void shouldMapId() {
			var kommentar = callMapper();

			assertThat(kommentar.getId()).isEqualTo(KommentarTestFactory.ID);
		}

		@Test
		void shouldMapText() {
			var kommentar = callMapper();

			assertThat(kommentar.getText()).isEqualTo(KommentarTestFactory.TEXT);
		}

		@Test
		void shouldMapCreatedBy() {
			var kommentar = callMapper();

			assertThat(kommentar.getCreatedBy()).isEqualTo(KommentarTestFactory.CREATED_BY);
		}

		@Test
		void shouldMapCreatedAt() {
			var kommentar = callMapper();

			assertThat(kommentar.getCreatedAt()).isEqualTo(KommentarTestFactory.CREATED_AT);
		}

		@Test
		void shouldMapAttachments() {
			var kommentar = callMapper();

			assertThat(kommentar.getAttachments()).containsExactlyElementsOf(KommentarTestFactory.ATTACHMENTS);
		}

		private Kommentar callMapper() {
			return kommentarMapper.fromItem(GrpcKommentarTestFactory.create());
		}
	}
}
