/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.postfach;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.apache.commons.lang3.StringUtils;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.archive.common.TimeMapper;

class PostfachMailMapperTest {

	@InjectMocks
	private final PostfachMailMapper mapper = Mappers.getMapper(PostfachMailMapper.class);

	@Mock
	private TimeMapper timeMapper;

	@Nested
	class TestToPostfachMail {

		@BeforeEach
		void initMock() {
			when(timeMapper.parseString(PostfachMailTestFactory.CREATED_AT_STR)).thenReturn(PostfachMailTestFactory.CREATED_AT);
			when(timeMapper.parseString(PostfachMailTestFactory.SENT_AT_STR)).thenReturn(PostfachMailTestFactory.SENT_AT);
		}

		@Test
		void shouldMapCreatedAt() {
			toPostfachMail();

			verify(timeMapper).parseString(PostfachMailTestFactory.CREATED_AT_STR);
		}

		@Test
		void shouldMapSentAt() {
			toPostfachMail();

			verify(timeMapper).parseString(PostfachMailTestFactory.SENT_AT_STR);
		}

		@Test
		void shouldMapFields() {
			var postfachMail = toPostfachMail();

			assertThat(postfachMail).usingRecursiveComparison().isEqualTo(PostfachMailTestFactory.create());
		}

		@Test
		void shouldMapEmptyCreatedByToNull() {
			var postfachMail = mapper.toPostfachMail(GrpcPostfachMailTestFactory.createBuilder().setCreatedBy(StringUtils.EMPTY).build());

			assertThat(postfachMail.getCreatedBy()).isNull();
		}

		private PostfachMail toPostfachMail() {
			return mapper.toPostfachMail(GrpcPostfachMailTestFactory.create());
		}
	}
}