/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import static org.assertj.core.api.Assertions.*;

import java.time.LocalDate;
import java.time.ZonedDateTime;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.NullSource;
import org.junit.jupiter.params.provider.ValueSource;
import org.mapstruct.factory.Mappers;

import de.xoev.xdomea.DatatypeType;

class DatatypeMapperTest {

	private final DatatypeMapper datatypeMapper = Mappers.getMapper(DatatypeMapper.class);

	@DisplayName("should return DatatypeType STRING when")
	@ParameterizedTest(name = "\"{0}\"")
	@NullSource
	@ValueSource(strings = { StringUtils.EMPTY, "a" })
	void shouldReturnString(String arg) {
		var datatype = datatypeMapper.from(arg);

		assertThat(datatype).isEqualTo(DatatypeType.STRING);
	}

	@Test
	void shouldReturnStringAsDefault() {
		var datatype = datatypeMapper.from(new Object());

		assertThat(datatype).isEqualTo(DatatypeType.STRING);
	}

	@Test
	void shouldReturnDate() {
		var datatype = datatypeMapper.from(LocalDate.now());

		assertThat(datatype).isEqualTo(DatatypeType.DATE);
	}

	@Test
	void shouldReturnDatetime() {
		var datatype = datatypeMapper.from(ZonedDateTime.now());

		assertThat(datatype).isEqualTo(DatatypeType.DATETIME);
	}

	@Test
	void shouldReturnInteger() {
		var datatype = datatypeMapper.from(1);

		assertThat(datatype).isEqualTo(DatatypeType.INTEGER);
	}

	@Test
	void shouldReturnFloat() {
		var datatype = datatypeMapper.from(1.0f);

		assertThat(datatype).isEqualTo(DatatypeType.FLOAT);
	}

	@Test
	void shouldReturnBoolean() {
		var datatype = datatypeMapper.from(true);

		assertThat(datatype).isEqualTo(DatatypeType.BOOLEAN);
	}

	@Test
	void shouldReturnTypeOfElementsInCollection() {
		var datatype = datatypeMapper.from(List.of(1, 2));

		assertThat(datatype).isEqualTo(DatatypeType.INTEGER);
	}

	@Test
	void shouldReturnDefaultIfCollectionIsEmpty() {
		var datatype = datatypeMapper.from(new Object[] {});

		assertThat(datatype).isEqualTo(DatatypeType.STRING);
	}
}