/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.archive.vorgang;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.vorgang.common.grpc.GrpcFormDataMapper;
import de.ozgcloud.vorgang.vorgang.GrpcVorgangWithEingang;

class VorgangWithEingangMapperTest {

	@InjectMocks
	private final VorgangWithEingangMapper mapper = Mappers.getMapper(VorgangWithEingangMapper.class);

	@Mock
	private GrpcFormDataMapper grpcFormDataMapper;

	@Nested
	class TestFromGrpc {

		private final GrpcVorgangWithEingang grpcVorgangWithEingang = GrpcVorgangWithEingangTestFactory.create();

		@Test
		void shouldMapToVorgangWithEingang() {
			mockGrpcFormDataMapper();

			var vorgangWithEingang = mapper.fromGrpc(grpcVorgangWithEingang);

			assertThat(vorgangWithEingang).usingRecursiveComparison().isEqualTo(VorgangWithEingangTestFactory.create());
		}

		private void mockGrpcFormDataMapper() {
			when(grpcFormDataMapper.mapFromFormData(GrpcAntragstellerTestFactory.OTHER_DATA)).thenReturn(AntragstellerTestFactory.OTHER_DATA);
			when(grpcFormDataMapper.mapFromFormData(GrpcEingangTestFactory.FORM_DATA)).thenReturn(EingangTestFactory.AS_MAP);
		}
	}
}
